@@ -1,19 +1,24 @@
-## Copyright (C) 2002 Etienne Grossmann.  All rights reserved.
+## Copyright (C) 2002 Etienne Grossmann <etienne@egdn.net>
 ##
-## This program is free software; you can redistribute it and/or modify it
-## under the terms of the GNU General Public License as published by the
-## Free Software Foundation; either version 2, or (at your option) any
-## later version.
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
 ##
-## This is distributed in the hope that it will be useful, but WITHOUT
+## This program is distributed in the hope that it will be useful, but WITHOUT
 ## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-## for more details.
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+##
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## [x,v,flag,out,df,d2f] = fminunc_compat (f,x,opt,...) - M*tlab-like optimization
 ##
 ## Imitation of m*tlab's fminunc(). The optional 'opt' argument is a struct,
-## e.g. produced by 'optimset()'.
+## e.g. produced by 'optimset()'. 'fminunc_compat' has been deprecated in
+## favor of 'fminunc', which is now part of core Octave. This function
+## will possibly be removed from future versions of the 'optim' package.
 ##
 ## Supported options
 ## -----------------
@@ -40,8 +45,16 @@
 ##                         the 'backend' option of minimize().
 ##
 ## This function is a front-end to minimize().
+
 function [x,fval,flag,out,df,d2f] = fminunc_compat (fun,x0,opt,varargin)
 
+  persistent warned = false;
+  if (! warned)
+    warned = true;
+    warning ("Octave:deprecated-function",
+             "`fminunc_compat' has been deprecated, and will be removed in the future. Use `fminunc' from Octave core instead.");
+  endif
+
 if nargin < 3, opt = struct (); end
 if nargin > 3, 
   args = {x0, varargin{:}};
