@@ -1,24 +1,21 @@
 ## Copyright (C) 2010, 2011 Olaf Till <olaf.till@uni-jena.de>
 ##
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or
-## (at your option) any later version.
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
 ##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
 ##
-## You should have received a copy of the GNU General Public License
-## along with this program; If not, see <http://www.gnu.org/licenses/>.
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-##
 ## @deftypefn {Function File} {[@var{p}, @var{fy}, @var{cvg}, @var{outp}] =} nonlin_curvefit (@var{f}, @var{pin}, @var{x}, @var{y})
-##
 ## @deftypefnx {Function File} {[@var{p}, @var{fy}, @var{cvg}, @var{outp}] =} nonlin_curvefit (@var{f}, @var{pin}, @var{x}, @var{y}, @var{settings})
-##
 ## Frontend for nonlinear fitting of values, computed by a model
 ## function, to observed values.
 ##
@@ -35,7 +32,6 @@
 ## which will be set to @var{x}.
 ##
 ## @seealso {nonlin_residmin}
-##
 ## @end deftypefn
 
 function [p, fy, cvg, outp] = nonlin_curvefit (f, pin, x, y, settings)
@@ -85,3 +81,21 @@ function ret = __optimget__ (s, name, default)
   endif
 
 endfunction
+
+%!demo
+%!  ## Example for linear inequality constraints
+%!  ## (see also the same example in 'demo nonlin_residmin')
+%!
+%!  ## independents and observations
+%!  indep = 1:5;
+%!  obs = [1, 2, 4, 7, 14];
+%!  ## model function:
+%!  f = @ (p, x) p(1) * exp (p(2) * x);
+%!  ## initial values:
+%!  init = [.25; .25];
+%!  ## linear constraints, A.' * parametervector + B >= 0
+%!  A = [1; -1]; B = 0; # p(1) >= p(2);
+%!  settings = optimset ("inequc", {A, B});
+%!
+%!  ## start optimization
+%!  [p, model_values, cvg, outp] = nonlin_curvefit (f, init, indep, obs, settings)
