@@ -1,26 +1,25 @@
 ## Copyright (C) 2010, 2011 Olaf Till <olaf.till@uni-jena.de>
 ##
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or
-## (at your option) any later version.
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
 ##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
 ##
-## You should have received a copy of the GNU General Public License
-## along with this program; If not, see <http://www.gnu.org/licenses/>.
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-##
 ## @deftypefn {Function File} {[@var{p}, @var{resid}, @var{cvg}, @var{outp}] =} nonlin_residmin (@var{f}, @var{pin})
-##
 ## @deftypefnx {Function File} {[@var{p}, @var{resid}, @var{cvg}, @var{outp}] =} nonlin_residmin (@var{f}, @var{pin}, @var{settings})
-##
 ## Frontend for nonlinear minimization of residuals returned by a model
-## function. The functions supplied by the user have a minimal
+## function.
+##
+## The functions supplied by the user have a minimal
 ## interface; any additionally needed constants (e.g. observed values)
 ## can be supplied by wrapping the user functions into anonymous
 ## functions.
@@ -91,7 +90,8 @@
 ## intervals should be used by jacobian functions performing finite
 ## differencing. Default: @code{false (size (parameters))}.
 ##
-## @code{complex_step_derivative}, @code{complex_step_derivative_inequc},
+## @code{complex_step_derivative_f},
+## @code{complex_step_derivative_inequc},
 ## @code{complex_step_derivative_equc}: logical scalars, default: false.
 ## Estimate Jacobian of model function, general inequality constraints,
 ## and general equality constraints, respectively, with complex step
@@ -129,21 +129,25 @@
 ## @code{h (p[, idx]) >= 0}; @code{p} is the column vector of optimized
 ## paraters and the optional argument @code{idx} is a logical index.
 ## @code{h} has to return the values of all constraints if @code{idx} is
-## not given, and has to return only the indexed constraints if
+## not given. It may choose to return only the indexed constraints if
 ## @code{idx} is given (so computation of the other constraints can be
-## spared). In gradient determination, this function may be called with
-## an informational third argument, whose content depends on the
-## function for gradient determination. If a second entry for general
-## inequality constraints is given, it must be a function computing the
-## jacobian of the constraints with respect to the parameters. For this
-## function, the description of @code{dfdp} above applies, except that
-## it is called with 3 arguments since it has an additional argument
-## @code{idx} --- a logical index --- at second position, indicating
-## which rows of the jacobian must be returned, and except that the
-## default function calls @code{h} with 3 arguments, since the argument
-## @code{idx} is also supplied. Note that specifying linear constraints
-## as general constraints will generally waste performance, even if
-## further, non-linear, general constraints are also specified.
+## spared); in this case, the additional setting @code{inequc_f_idx} has
+## to be set to @code{true}. In gradient determination, this function
+## may be called with an informational third argument, whose content
+## depends on the function for gradient determination. If a second entry
+## for general inequality constraints is given, it must be a function
+## computing the jacobian of the constraints with respect to the
+## parameters. For this function, the description of @code{dfdp} above
+## applies, with 2 exceptions: 1) it is called with 3 arguments since it
+## has an additional argument @code{idx} --- a logical index --- at
+## second position, indicating which rows of the jacobian must be
+## returned (if the function chooses to return only indexed rows, the
+## additional setting @code{inequc_df_idx} has to be set to
+## @code{true}). 2) the default jacobian function calls @code{h} with 3
+## arguments, since the argument @code{idx} is also supplied. Note that
+## specifying linear constraints as general constraints will generally
+## waste performance, even if further, non-linear, general constraints
+## are also specified.
 ##
 ## @code{equc}: Equality constraints. Specified the same way as
 ## inequality constraints (see @code{inequc}).
@@ -177,7 +181,7 @@
 ##
 ## @code{plot_cmd}: Function enabling backend to plot results or
 ## intermediate results. Will be called with current computed
-## residualse. Default: plot nothing.
+## residuals. Default: plot nothing.
 ##
 ## @code{debug}: Logical scalar, default: @code{false}. Will be passed
 ## to the backend, which might print debugging information if true.
@@ -259,7 +263,6 @@
 ## method, with descent in each gradient component; for testing only.
 ##
 ## @seealso {nonlin_curvefit}
-##
 ## @end deftypefn
 
 function [p, resid, cvg, outp] = nonlin_residmin (varargin)
@@ -282,3 +285,20 @@ function [p, resid, cvg, outp] = nonlin_residmin (varargin)
   [p, resid, cvg, outp] = __nonlin_residmin__ (varargin{:});
 
 endfunction
+
+%!demo
+%!  ## Example for linear inequality constraints
+%!  ## (see also the same example in 'demo nonlin_curvefit')
+%!
+%!  ## independents
+%!  indep = 1:5;
+%!  ## residual function:
+%!  f = @ (p) p(1) * exp (p(2) * indep) - [1, 2, 4, 7, 14];
+%!  ## initial values:
+%!  init = [.25; .25];
+%!  ## linear constraints, A.' * parametervector + B >= 0
+%!  A = [1; -1]; B = 0; # p(1) >= p(2);
+%!  settings = optimset ("inequc", {A, B});
+%!
+%!  ## start optimization
+%!  [p, residuals, cvg, outp] = nonlin_residmin (f, init, settings)
