@@ -31,6 +31,12 @@ function [p, resid, cvg, outp] = \
     optimget = @ __optimget__;
   endif
 
+  if (compare_versions (version (), "3.2.4", "<="))
+    ## For bug #31484; but Octave 3.6... shows bug #36288 due to this
+    ## workaround. Octave 3.7... seems to be all right.
+    __dfdp__ = @ __dfdp__;
+  endif
+
   ## some scalar defaults; some defaults are backend specific, so
   ## lacking elements in respective constructed vectors will be set to
   ## NA here in the frontend
@@ -56,13 +62,17 @@ function [p, resid, cvg, outp] = \
 		  "fract_prec", [], \
 		  "diffp", [], \
 		  "diff_onesided", [], \
-		  "complex_step_derivative", false, \
+		  "complex_step_derivative_f", false, \
 		  "complex_step_derivative_inequc", false, \
 		  "complex_step_derivative_equc", false, \
 		  "cstep", cstep_default, \
 		  "fixed", [], \
 		  "inequc", [], \
 		  "equc", [], \
+                  "inequc_f_idx", false, \
+                  "inequc_df_idx", false, \
+                  "equc_f_idx", false, \
+                  "equc_df_idx", false, \
 		  "weights", [], \
 		  "TolFun", stol_default, \
 		  "MaxIter", [], \
@@ -112,10 +122,10 @@ function [p, resid, cvg, outp] = \
   diffp = optimget (settings, "diffp");
   diff_onesided = optimget (settings, "diff_onesided");
   fixed = optimget (settings, "fixed");
-  do_cstep = optimget (settings, "complex_step_derivative", false);
+  do_cstep = optimget (settings, "complex_step_derivative_f", false);
   cstep = optimget (settings, "cstep", cstep_default);
   if (do_cstep && ! isempty (dfdp))
-    error ("both 'complex_step_derivative' and 'dfdp' are set");
+    error ("both 'complex_step_derivative_f' and 'dfdp' are set");
   endif
   do_cstep_inequc = \
       optimget (settings, "complex_step_derivative_inequc", false);
@@ -136,12 +146,35 @@ function [p, resid, cvg, outp] = \
   mc_struct = isstruct (mc);
   emc_struct = isstruct (emc);
 
-  ## correct "_pstruct" settings if functions are not supplied
+  ## correct "_pstruct" settings if functions are not supplied, handle
+  ## constraint functions not honoring indices
   if (isempty (dfdp)) dfdp_pstruct = false; endif
-  if (isempty (f_genicstr)) f_inequc_pstruct = false; endif
-  if (isempty (f_genecstr)) f_equc_pstruct = false; endif
-  if (! user_df_gencstr) df_inequc_pstruct = false; endif
-  if (! user_df_genecstr) df_equc_pstruct = false; endif
+  if (isempty (f_genicstr))
+    f_inequc_pstruct = false;
+  elseif (! optimget (settings, "inequc_f_idx", false))
+    f_genicstr = @ (p, varargin) apply_idx_if_given \
+        (f_genicstr (p, varargin{:}), varargin{:});
+  endif
+  if (isempty (f_genecstr))
+    f_equc_pstruct = false;
+  elseif (! optimget (settings, "equc_f_idx", false))
+    f_genecstr = @ (p, varargin) apply_idx_if_given \
+        (f_genecstr (p, varargin{:}), varargin{:});
+  endif
+  if (user_df_gencstr)
+    if (! optimget (settings, "inequc_df_idx", false))
+      df_gencstr = @ (varargin) df_gencstr (varargin{:})(varargin{2}, :);
+    endif
+  else
+    df_inequc_pstruct = false;
+  endif
+  if (user_df_genecstr)
+    if (! optimget (settings, "equc_df_idx", false))
+      df_genecstr = @ (varargin) df_genecstr (varargin{:})(varargin{2}, :);
+    endif
+  else
+    df_equc_pstruct = false;
+  endif
 
   ## some settings require a parameter order
   if (pin_struct || ! isempty (pconf) || f_inequc_pstruct || \
@@ -458,7 +491,6 @@ function [p, resid, cvg, outp] = \
     if (do_cstep)
       dfdp = @ (p, hook) jacobs (p, f, hook);
     else
-      __dfdp__ = @ __dfdp__; # for bug #31484 (Octave <= 3.2.4)
       dfdp = @ (p, hook) __dfdp__ (p, f, hook);
     endif
   endif
@@ -814,8 +846,8 @@ function [p, resid, cvg, outp] = \
   tp = eye (sum (nonfixed));
   lidx = lbound != - Inf;
   uidx = ubound != Inf;
-  mc = cat (2, mc, tp(:, lidx), - tp(:, uidx));
-  vc = cat (1, vc, - lbound(lidx, 1), ubound(uidx, 1));
+  mc = cat (2, tp(:, lidx), - tp(:, uidx), mc);
+  vc = cat (1, - lbound(lidx, 1), ubound(uidx, 1), vc);
 
   ## concatenate linear inequality and equality constraints
   mc = cat (2, mc, emc);
@@ -990,3 +1022,11 @@ function ret = __optimget__ (s, name, default)
   endif
 
 endfunction
+
+function ret = apply_idx_if_given  (ret, varargin)
+
+  if (nargin > 1)
+    ret = ret(varargin{1});
+  endif
+
+endfunction
