@@ -1,14 +1,17 @@
-## Copyright (C) 2002 Etienne Grossmann.  All rights reserved.
+## Copyright (C) 2002 Etienne Grossmann <etienne@egdn.net>
 ##
-## This program is free software; you can redistribute it and/or modify it
-## under the terms of the GNU General Public License as published by the
-## Free Software Foundation; either version 2, or (at your option) any
-## later version.
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
 ##
-## This is distributed in the hope that it will be useful, but WITHOUT
+## This program is distributed in the hope that it will be useful, but WITHOUT
 ## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-## for more details.
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+##
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## Test whether d2_min() functions correctly, with two args
 ##
@@ -18,8 +21,6 @@
 ##
 ## If a variables "verbose" is set, then some comments are output.
 
-## Author:        Etienne Grossmann <etienne@cs.uky.edu>
-
 1 ;
 
 ok = 0;
@@ -60,7 +61,7 @@ endfunction
 ## Returns the cputime since last call to 'mytic'.
 
 function dt = mytic()
-   static last_mytic = 0 ;
+   persistent last_mytic = 0 ;
    [t,u,s] = cputime() ;
    dt = t - last_mytic ;
    last_mytic = t ;
